powered by
Performs a simple compatibility check between historical and current data to help guide the choice of discounting parameter.
check_compatibility(historical_data, current_data, alpha = 0.05)
A list with compatibility test results
Historical data
Current data
Significance level for compatibility test (default: 0.05)
set.seed(123) historical <- rnorm(50, mean = 10, sd = 2) current <- rnorm(30, mean = 10.5, sd = 2) compatibility <- check_compatibility(historical, current) print(compatibility)
Run the code above in your browser using DataLab